var structzypp_1_1ResTraits_3_01ResObject_01_4 =
[
    [ "KindType", "structzypp_1_1ResTraits_3_01ResObject_01_4.html#adad9cd3782dda863ff5fd2536cea5f0f", null ],
    [ "PtrType", "structzypp_1_1ResTraits_3_01ResObject_01_4.html#a8c5373ddee35311168ad5109d9cb7ca4", null ],
    [ "constPtrType", "structzypp_1_1ResTraits_3_01ResObject_01_4.html#abc553b2b1471f1460df398a350c9cd09", null ],
    [ "isPseudoInstalled", "structzypp_1_1ResTraits.html#ae366188b4da28204303814d46329d59d", null ],
    [ "ZYPP_API", "structzypp_1_1ResTraits.html#a0dc77ee0f4786ddf6d17c56e46e431ff", null ]
];